"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Hero = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const ChannelValue_1 = require("../ChannelValue");
const Icon_1 = require("../Icon");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const makeStyles = (theme, fontScale) => react_native_1.StyleSheet.create({
    root: {
        flex: 1,
        alignItems: 'center',
        justifyContent: 'center',
        paddingHorizontal: 8,
        paddingVertical: 16,
    },
    iconWrapper: {
        padding: 0,
        marginBottom: 8 * fontScale,
        alignItems: 'center',
        justifyContent: 'center',
        overflow: 'hidden',
        borderRadius: 50,
    },
    values: {
        flexDirection: 'row',
        justifyContent: 'center',
        alignItems: 'center',
        maxWidth: '100%',
    },
    label: {
        width: '100%',
        overflow: 'hidden',
        textAlign: 'center',
        fontFamily: 'OpenSans-SemiBold',
        fontWeight: '600',
        color: theme.colors.onSurfaceVariant,
    },
});
/**
 * [Hero](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--hero) component
 *
 * The `<Hero>` component displays a particular icon, value/units, and a label. The icon property will accept any valid component - this will typically be a Material icon, [Brightlayer UI icon](https://github.com/etn-ccis/blui-icons), or [Progress Icon](https://github.com/etn-ccis/blui-progress-icons). It will also accept Text/Emoji values.
 */
const Hero = (props) => {
    const { label, ChannelValueProps, onPress, icon, iconColor, iconSize, children, iconBackgroundColor, styles = {}, style, theme: themeOverride, ...viewProps } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = makeStyles(theme, fontScale);
    const normalizeIconSize = (0, react_1.useCallback)(() => {
        if (!iconSize)
            return 36;
        return Math.max(10, Math.min(48, iconSize));
    }, [iconSize]);
    const getColor = (0, react_1.useCallback)((color) => color || theme.colors.onSurfaceVariant, [theme]);
    const getIcon = (0, react_1.useCallback)(() => {
        if (icon) {
            return react_1.default.createElement(Icon_1.Icon, { source: icon, size: normalizeIconSize(), color: getColor(iconColor) });
        }
    }, [icon, normalizeIconSize, getColor, iconColor]);
    return (react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: onPress, disabled: !onPress, style: [defaultStyles.root, styles.root, style], ...viewProps },
        react_1.default.createElement(react_native_1.View, { style: [
                defaultStyles.iconWrapper,
                {
                    backgroundColor: iconBackgroundColor || 'rgba(255, 255, 255, 0)',
                    height: typeof iconSize === 'number' ? normalizeIconSize() : iconSize ?? 36 * fontScale,
                    width: typeof iconSize === 'number' ? normalizeIconSize() : iconSize ?? 36 * fontScale,
                },
                styles.iconWrapper,
            ] }, getIcon()),
        react_1.default.createElement(react_native_1.View, { style: [defaultStyles.values, styles.values] },
            !children && !!ChannelValueProps?.value && react_1.default.createElement(ChannelValue_1.ChannelValue, { fontSize: 22, ...ChannelValueProps }),
            children),
        react_1.default.createElement(react_native_paper_1.Text, { variant: 'titleMedium', style: [defaultStyles.label, styles.label], numberOfLines: 1, ellipsizeMode: 'tail' }, label)));
};
exports.Hero = Hero;
