"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ListItemTag = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
const shared_1 = require("../Utility/shared");
const react_native_themes_1 = require("@brightlayer-ui/react-native-themes");
const listItemTagStyles = (props, theme, fontScale, fontSize) => react_native_1.StyleSheet.create({
    root: {
        backgroundColor: props.backgroundColor || theme.colors.primaryFilledContainer,
        color: props.fontColor || theme.colors.onPrimaryFilledContainer,
        height: (0, shared_1.calculateHeight)(fontSize) * fontScale,
        padding: 0,
        paddingLeft: 4 * fontScale,
        paddingRight: 3 * fontScale,
        borderRadius: 4 * fontScale,
        fontWeight: '700',
        fontFamily: 'OpenSans-Bold',
        overflow: 'hidden',
        lineHeight: (0, shared_1.calculateHeight)(fontSize),
        fontSize,
        letterSpacing: 1,
        textTransform: 'uppercase',
    },
});
/**
 * [ListItemTag](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--list-item-tag) component
 *
 * This component is primarily used as a tag for list elements. It is a stylized
 * text item with a colored background and rounded corners.
 */
const ListItemTag = (props) => {
    const { label, style, styles = {}, theme: themeOverride, 
    /* eslint-disable @typescript-eslint/no-unused-vars */
    fontColor, backgroundColor, 
    /* eslint-enable @typescript-eslint/no-unused-vars */
    ...otherTextProps } = props;
    const theme = (0, react_native_themes_1.useExtendedTheme)(themeOverride);
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const defaultStyles = listItemTagStyles(props, theme, fontScale, props.fontSize || 10);
    return (react_1.default.createElement(react_native_paper_1.Text, { variant: 'bodyMedium', style: [defaultStyles.root, styles.root, style], ...otherTextProps }, label));
};
exports.ListItemTag = ListItemTag;
exports.ListItemTag.displayName = 'ListItemTag';
